# coding=utf-8

import logging
import tempfile

from django.conf import settings
from django.test import TestCase

from web.importer import SubjectExporterCronJob

logger = logging.getLogger(__name__)
from django.core import mail
from django_cron.models import CronJobLog


class TestCronJobExporter(TestCase):

    def setUp(self):
        setattr(settings, "DAILY_SUBJECT_EXPORT_FILE", None)

    def tearDown(self):
        setattr(settings, "DAILY_SUBJECT_EXPORT_FILE", None)

    def test_import_without_configuration(self):
        CronJobLog.objects.all().delete()

        job = SubjectExporterCronJob()

        status = job.do()

        self.assertEqual("export file not defined", status)
        self.assertEqual(0, len(mail.outbox))

    def test_import(self):
        new_file, tmp = tempfile.mkstemp()

        setattr(settings, "DAILY_SUBJECT_EXPORT_FILE", tmp)
        CronJobLog.objects.all().delete()

        job = SubjectExporterCronJob()

        status = job.do()

        self.assertEqual("export is successful", status)
        self.assertEqual(1, len(mail.outbox))
